@@ -4,7 +4,9 @@ from .functions import (
     batch_fetch,
     defer_except,
     escape_like,
+    identity,
     primary_keys,
+    naturally_equivalent,
     render_statement,
     render_expression,
     create_mock_engine,
@@ -45,7 +47,7 @@ from .types import (
 )
 
 
-__version__ = '0.19.0'
+__version__ = '0.20.0'
 
 
 __all__ = (
@@ -55,8 +57,10 @@ __all__ = (
     escape_like,
     generates,
     generic_relationship,
+    identity,
     instrumented_list,
     merge,
+    naturally_equivalent,
     primary_keys,
     proxy_dict,
     render_statement,
