@@ -1,21 +1,21 @@
 import six
 
+ip_address = None
 try:
     from ipaddress import ip_address
-
 except ImportError:
     try:
         from ipaddr import IPAddress as ip_address
-
     except ImportError:
-        ip_address = None
+        pass
 
 
 from sqlalchemy import types
 from sqlalchemy_utils import ImproperlyConfigured
+from .scalar_coercible import ScalarCoercible
 
 
-class IPAddressType(types.TypeDecorator):
+class IPAddressType(types.TypeDecorator, ScalarCoercible):
     """
     Changes IPAddress objects to a string representation on the way in and
     changes them back to IPAddress objects on the way out.
@@ -39,5 +39,5 @@ class IPAddressType(types.TypeDecorator):
     def process_result_value(self, value, dialect):
         return ip_address(value) if value else None
 
-    def coercion_listener(self, target, value, oldvalue, initiator):
+    def _coerce(self, value):
         return ip_address(value) if value else None
